==> ds-bootstrap-0.3.0-alpha.1.tgz: package/esm/Widgets/SimpleList/SimpleList.js <==
import React from 'react';
import { TransTitle, extractValue, memo, PluginStack } from '@ui-schema/ui-schema';
import { List } from 'immutable';
import { ValidityHelperText } from '../../Component/LocaleHelperText/LocaleHelperText';
import { IconPlus, IconMinus } from '@ui-schema/ds-bootstrap/Component/Icons/Icons';
const SimpleList = extractValue(memo(({
  storeKeys,
  ownKey,
  schema,
  value,
  onChange,
  showValidity,
  errors,
  required
}) => {
  let btnSize = schema.getIn(['view', 'btnSize']) || 'small';
  let classFormGroup = ['form-group', 'd-flex', 'align-items-center'];
  let classFormControl = ['form-control'];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classFormGroup.push('was-validated');
  }

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  }), /*#__PURE__*/React.createElement("div", null, value ? value.map((val, i) => /*#__PURE__*/React.createElement("div", {
    key: i,
    className: classFormGroup.join(' ')
  }, /*#__PURE__*/React.createElement(PluginStack, {
    className: classFormControl.join(' '),
    showValidity: showValidity,
    storeKeys: storeKeys.push(i),
    parentSchema: schema,
    schema: schema.get('items'),
    required: required,
    noGrid: true
  }), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(IconMinus, {
    btnSize: btnSize,
    onClick: () => {
      onChange(storeKeys, ['value'], {
        type: 'update',
        update: ({
          value: storeValue
        }) => ({
          value: storeValue.splice(i, 1)
        }),
        schema,
        required
      });
    }
  })))).valueSeq() : null, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(IconPlus, {
    btnSize: btnSize,
    onClick: () => {
      onChange(storeKeys, ['value'], {
        type: 'update',
        update: ({
          value: storeValue = List()
        }) => ({
          value: storeValue.push('')
        }),
        schema,
        required
      });
    }
  }))), /*#__PURE__*/React.createElement(ValidityHelperText
  /* only pass down errors which are not for a specific sub-schema */
  , {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
}));
export { SimpleList };

==> ds-bootstrap-0.4.0-alpha.1.tgz: package/esm/Widgets/SimpleList/SimpleList.js <==
import React from 'react';
import { TransTitle, extractValue, memo, PluginStack } from '@ui-schema/ui-schema';
import { List } from 'immutable';
import { ValidityHelperText } from '../../Component/LocaleHelperText/LocaleHelperText';
import { IconPlus, IconMinus } from '@ui-schema/ds-bootstrap/Component/Icons/Icons';
const SimpleList = extractValue(memo(({
  storeKeys,
  schema,
  value,
  onChange,
  showValidity,
  errors,
  required
}) => {
  let btnSize = schema.getIn(['view', 'btnSize']) || 'small';
  let classFormGroup = ['form-group', 'd-flex', 'align-items-center'];
  let classFormControl = ['form-control'];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classFormGroup.push('was-validated');
  }

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys
  }), /*#__PURE__*/React.createElement("div", null, value ? value.map((val, i) => /*#__PURE__*/React.createElement("div", {
    key: i,
    className: classFormGroup.join(' ')
  }, /*#__PURE__*/React.createElement(PluginStack, {
    className: classFormControl.join(' '),
    showValidity: showValidity,
    storeKeys: storeKeys.push(i),
    parentSchema: schema,
    schema: schema.get('items'),
    required: required,
    noGrid: true
  }), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(IconMinus, {
    btnSize: btnSize,
    onClick: () => {
      onChange({
        storeKeys,
        scopes: ['value'],
        type: 'update',
        updater: ({
          value: storeValue
        }) => ({
          value: storeValue.splice(i, 1)
        }),
        schema,
        required
      });
    }
  })))).valueSeq() : null, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(IconPlus, {
    btnSize: btnSize,
    onClick: () => {
      onChange({
        storeKeys,
        scopes: ['value'],
        type: 'update',
        updater: ({
          value: storeValue = List()
        }) => ({
          value: storeValue.push('')
        }),
        schema,
        required
      });
    }
  }))), /*#__PURE__*/React.createElement(ValidityHelperText
  /* only pass down errors which are not for a specific sub-schema */
  , {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
}));
export { SimpleList };
